# sage_setup: distribution = sagemath-combinat
from sage.sat.solvers.cryptominisat import CryptoMiniSat
from sage.sat.solvers.dimacs import Glucose, GlucoseSyrup, Kissat, RSat
from sage.sat.solvers.satsolver import SatSolver



# sage_setup: distribution = sagemath-combinat
from sage.rings.all__sagemath_categories import *

from sage.misc.lazy_import import lazy_import

# Lazy combinatorial species
lazy_import('sage.rings.lazy_species', 'LazyCombinatorialSpecies')

del lazy_import



# sage_setup: distribution = sagemath-combinat
import pytest


def test_positive_integer_semigroup():
    r"""
    Run the ``TestSuite()`` for ``PositiveIntegerSemigroup``
    (this can take quite a long time).
    """
    from sage.misc.sage_unittest import TestSuite
    from sage.combinat.backtrack import PositiveIntegerSemigroup
    PP = PositiveIntegerSemigroup()

    # fewer max_runs since these are kind of slow
    TestSuite(PP).run(verbose=True,
                      raise_on_failure=True,
                      max_runs=256)
